import { isVNode, createTextVNode, h } from 'vue';
import { u as useI18n } from './shared/vue-intl-controller.f5796960.mjs';
import './shared/vue-intl-controller.631d1212.mjs';

function createObject() {
  return /* @__PURE__ */ Object.create(null);
}
function isObject(value) {
  return value != null && typeof value === "object";
}
function isPropsWithMessageID(value) {
  return isObject(value) && ("messageId" in value || "message-id" in value);
}
function isPropsWithMessage(value) {
  return isObject(value) && "message" in value;
}
function getMessageID(props) {
  if ("message-id" in props) {
    return props["message-id"];
  }
  return props.messageId;
}
function IntlFormatted(props, context) {
  if (!isPropsWithMessageID(props) && !isPropsWithMessage(props)) {
    throw new Error(
      'IntlFormatted cannot be rendered without "message-id" or "message" properties'
    );
  }
  const { intl, normalizeMessageDescriptor: getDescriptor } = useI18n();
  const initialValues = createObject();
  const values = createObject();
  if (props.values != null) {
    Object.assign(initialValues, props.values);
    Object.assign(values, initialValues);
  }
  if (Array.isArray(props.tags)) {
    for (const tag of props.tags) {
      let key;
      let component;
      if (Array.isArray(tag)) {
        key = tag[0];
        component = tag[1];
      } else {
        if (typeof tag !== "string") {
          throw new TypeError(
            "Custom components must be provided as array of [name, component]"
          );
        }
        key = tag;
        component = tag;
      }
      values[key] = (children) => {
        const newChildren = [];
        for (const child of children) {
          if (Array.isArray(child)) {
            newChildren.push(...child);
          } else {
            newChildren.push(
              isVNode(child) ? child : createTextVNode(String(child))
            );
          }
        }
        if (typeof component === "string") {
          return [h(component, newChildren)];
        } else {
          return [h(component, newChildren)];
        }
      };
    }
  } else if (props.tags != null) {
    throw new Error(
      'Property "tags" of IntlFormatted needs to be of array type or null / undefined'
    );
  }
  for (const [name, slot] of Object.entries(context.slots)) {
    if (!slot)
      continue;
    if (name.startsWith("~")) {
      const res = slot({
        values: initialValues
      });
      if (res != null) {
        if (res.length > 1) {
          throw new Error(
            `Slot argument "${name}" returned more than one child`
          );
        }
        values[name.slice(1)] = res[0];
      }
    } else {
      values[name] = (children) => {
        const res = slot({
          children,
          values: initialValues
        });
        if (res != null) {
          if (res.length > 1) {
            throw new Error(
              `Wrapping slot "${name}" returned more than one child`
            );
          }
          return res[0];
        }
        return "";
      };
    }
  }
  let formatted;
  if (isPropsWithMessage(props)) {
    formatted = intl.formatters.getMessageFormat(props.message, intl.locale, intl.formats).format(values);
  } else {
    const messageId = getMessageID(props);
    if (messageId != null) {
      formatted = intl.formatMessage(getDescriptor(messageId), values);
    } else {
      throw new Error(
        "Illegal state: neither message nor messageId properties provided"
      );
    }
  }
  return (Array.isArray(formatted) ? formatted.flat() : [formatted]).map(
    (child) => {
      return isVNode(child) ? child : createTextVNode(String(child));
    }
  );
}

function Fragment(props) {
  return Array.isArray(props.of) ? props.of : [props.of];
}

export { Fragment, IntlFormatted };
