import { d as MessagesMap } from './messages-d5f471aa.js';

type JSONPrimitive = string | number | boolean | null;
type JSONMap = {
    [key: string]: JSONValue;
};
type JSONArray = JSONValue[];
type JSONValue = JSONPrimitive | JSONArray | JSONMap;

declare global {
    namespace VueIntlController {
        /**
         * Represents a map of locale meta data object, used as
         * {@link LocaleDescriptor.meta} property.
         *
         * All values in this map should be JSON-serializable, therefore it extends
         * internal type {@link JSONMap}.
         */
        interface LocaleMeta extends JSONMap {
        }
        /**
         * Represents a map of associated with locale resources.
         *
         * These resources are loaded by the custom loaders, {@link IntlController}
         * has no means to load resources by itself to allow for more dynamic
         * configurations.
         */
        interface LocaleResources {
        }
    }
}
/**
 * Represents a descriptor for the locale.
 *
 * All values in this object should be JSON-serializable, therefore it extends
 * internal type {@link JSONMap}.
 */
interface LocaleDescriptor {
    /** BCP 47 language tag of the locale. */
    tag: string;
    /**
     * Meta data associated with the locale.
     *
     * It is useful when you need to have some data about locale available at all
     * times, for example its name that you display in UI, perhaps automatically
     * calculated data like % translated, etc.
     */
    meta?: VueIntlController.LocaleMeta;
}
/** Represents a locale object. */
interface Locale {
    /** Messages for the locale. */
    messages: MessagesMap;
    /** Resources for the locale. */
    resources: VueIntlController.LocaleResources;
}

export { LocaleDescriptor as L, Locale as a };
