import { App } from 'vue';
import { C as ControllerConfiguration, F as FormatAliases, I as IntlController } from './intl-dc152b78.js';
import { T as TranslateFunction } from './translateFunction-6f001285.js';
import './messages-d5f471aa.js';
import '@formatjs/intl';
import '@formatjs/icu-messageformat-parser';
import './locales-22b40efa.js';
import './sources-02c94682.js';
import './ErrorEvent-881212aa.js';
import 'intl-messageformat';
import '@braw/async-computed';

/** Represents options for the plugin. */
interface PluginOptions<ControllerType> {
    /** Options for the controller. */
    controllerOpts?: Partial<ControllerConfiguration<ControllerType>>;
    /**
     * Whether the plugin's properties will be automatically injected to all
     * instances of Vue.
     *
     * Set this to `false` if you want to utilise only composables instead.
     *
     * @default true // $t, $i18n, $fmt are automatically created in components.
     */
    globalMixin?: boolean;
    /** An array containing all additional injection sites besides Vue. */
    injectInto?: object[];
}
/** Represents the default for all injection descriptors. */
type DefaultDescriptorOverrides = {
    configurable: true;
};
type GetterOf<T> = Omit<PropertyDescriptor, 'get' | keyof DefaultDescriptorOverrides> & DefaultDescriptorOverrides & {
    get(): T;
    set?: undefined;
};
/** Represents global properties that are injected in `Vue.prototype`. */
interface PluginInjections<ControllerType> extends PropertyDescriptorMap {
    /** Injection for the formatting aliases. */
    $fmt: GetterOf<FormatAliases<ControllerType>>;
    /** Injection for the controller. */
    $i18n: GetterOf<IntlController<ControllerType>>;
    /** Injection for the translate function. */
    $t: GetterOf<TranslateFunction>;
}
type InjectedValues<Injections> = {
    [InjectionKey in keyof Injections as Injections[InjectionKey] extends {
        value: any;
    } ? InjectionKey : never]: Injections[InjectionKey] extends {
        value: infer ValueType;
    } ? ValueType : never;
};
type InjectedGetters<Injections> = {
    readonly [InjectionKey in keyof Injections as Injections[InjectionKey] extends {
        get(): any;
        set?: undefined;
    } ? InjectionKey : never]: Injections[InjectionKey] extends {
        get(): infer ValueType;
        set?: undefined;
    } ? ValueType : never;
};
type InjectedGettersAndSetters<Injections> = {
    [InjectionKey in keyof Injections as Injections[InjectionKey] extends {
        get(): any;
        set(value: any): void;
    } ? InjectionKey : never]: Injections[InjectionKey] extends {
        get(): infer ValueType;
        set(value: infer ValueType): void;
    } ? ValueType : never;
};
type InjectedProperties<ControllerType, Injections extends PluginInjections<ControllerType> = PluginInjections<ControllerType>> = InjectedValues<Injections> & InjectedGetters<Injections> & InjectedGettersAndSetters<Injections>;
interface Plugin<ControllerType> {
    /**
     * @returns Either previously created or newly instantiated controller
     *   instance.
     */
    getOrCreateController(): IntlController<ControllerType>;
    /** @returns A map of property descriptors that can be used for injecting. */
    getInjections(): PluginInjections<ControllerType>;
    /**
     * Creates a new object with `null` prototype and defines injections on it.
     *
     * @deprecated This will be removed in one of the next major releases.
     *
     *   Please access properties ({@link IntlController.formats},
     *   {@link IntlController.formatMessage}) directly on the controller instance
     *   that can be retrieved using {@link getOrCreateController}, or use:
     *
     *   ```ts
     *   Object.defineProperties(Object.create(null), plugin.getInjections())
     *   ```
     */
    toProperties(): InjectedProperties<ControllerType>;
    /**
     * Installs plugin in the provided Vue App in accordance to plugin options.
     *
     * @param app Vue App on which to install this plugin.
     */
    install(app: App): void;
}
declare function createPlugin<ControllerType = string>(opts?: PluginOptions<ControllerType>): Plugin<ControllerType>;

export { ControllerConfiguration, InjectedProperties, Plugin, PluginInjections, PluginOptions, createPlugin };
