import { c as createController } from './shared/vue-intl-controller.a3f40100.mjs';
import { g as createHashMap } from './shared/vue-intl-controller.041c4d65.mjs';
import { c as controllerKey } from './shared/vue-intl-controller.631d1212.mjs';
import '@formatjs/intl-localematcher';
import 'vue';
import '@formatjs/intl';
import '@braw/async-computed';

function createPlugin(opts) {
  let controllerInstance = null;
  function getOrCreateController() {
    if (controllerInstance == null) {
      controllerInstance = createController(opts?.controllerOpts);
    }
    return controllerInstance;
  }
  function getInjections() {
    const controller = getOrCreateController();
    return {
      $fmt: {
        configurable: true,
        get() {
          return controller.formats;
        }
      },
      $t: {
        configurable: true,
        get() {
          return controller.formatMessage;
        }
      },
      $i18n: {
        configurable: true,
        get() {
          return controller;
        }
      }
    };
  }
  return {
    getOrCreateController,
    getInjections,
    toProperties() {
      return Object.defineProperties(createHashMap(), getInjections());
    },
    install(app) {
      app.provide(controllerKey, getOrCreateController());
      if (opts?.globalMixin ?? true) {
        app.mixin({
          beforeCreate() {
            Object.defineProperties(this, getInjections());
          }
        });
      }
      if (opts?.injectInto != null) {
        const injections = getInjections();
        for (const injectionSite of opts.injectInto) {
          Object.defineProperties(injectionSite, injections);
        }
      }
    }
  };
}

export { createPlugin };
