function parseHeaderValue(value) {
  const languages = [];
  for (let part of value.split(",")) {
    part = part.trim();
    const [tag, ...valueParts] = part.split(";");
    const language = [tag, 1];
    for (const valuePart of valueParts) {
      const [key, value2, invalid] = valuePart.split("=");
      if (invalid != null) {
        throw new Error(`Illegal part "${part}"`);
      }
      if (key === "q") {
        const quality = Number(value2);
        if (isNaN(quality)) {
          throw new TypeError(`Expected a number for key "${key}": ${part}`);
        }
        language[1] = quality;
      }
    }
    languages.push(language);
  }
  return languages.sort((a, b) => b[1] - a[1]);
}
function useAcceptLanguageHeader(headerValue) {
  const preferredLanguages = [];
  if (headerValue != null && headerValue !== "") {
    for (const [language] of parseHeaderValue(headerValue)) {
      if (language === "*")
        continue;
      preferredLanguages.push(language);
    }
  }
  return {
    prefers: preferredLanguages.length > 0 ? preferredLanguages : null
  };
}

export { parseHeaderValue, useAcceptLanguageHeader };
