import { ref } from 'vue';

function useNavigatorLanguage() {
  const prefers = ref(null);
  if (typeof window === "undefined" || typeof navigator === "undefined") {
    console.warn(
      "No window and/or navigator API has been found in this environment. This source will be ineffective."
    );
    return { prefers };
  }
  function update() {
    if (typeof navigator === "undefined" || navigator == null) {
      prefers.value = null;
      return;
    }
    if ("languages" in navigator) {
      prefers.value = [...navigator.languages];
    } else {
      prefers.value = [navigator.language];
    }
  }
  function install() {
    window.addEventListener("languagechange", update);
    update();
  }
  function uninstall() {
    window.addEventListener("languagechange", update);
  }
  return {
    prefers,
    install,
    uninstall
  };
}

export { useNavigatorLanguage };
